@@ -18,6 +18,8 @@ AXIE_CONTRACT = "0x32950db2a7164ae833121501c797d79e7b79d74c"
 AXS_CONTRACT = "0x97a9107c1793bc407d6f527b77e7fff4d812bece"
 SLP_CONTRACT = "0xa8754b9fa15fc18bb59458815510e40a12cd2014"
 WETH_CONTRACT = "0xc99a6a985ed2cac1ef41640596c5a5f9f4e19ef5"
+USDC_CONTRACT = "0x0b7007c13325c48911f73a2dad5fa5dcbf808adc"
+SCATTER_CONTRACT = "0x14978681c5f8ce2f6b66d1f1551b0ec67405574c"
 RONIN_PROVIDER_FREE = "https://proxy.roninchain.com/free-gas-rpc"
 RONIN_PROVIDER = "https://api.roninchain.com/rpc"
 RETRIES = Retry(
@@ -27,25 +29,28 @@ RETRIES = Retry(
     allowed_methods=frozenset(['GET', 'POST'])
 )
 
+TOKENS = {
+    'slp': SLP_CONTRACT,
+    'axs': AXS_CONTRACT,
+    'axies': AXIE_CONTRACT,
+    'weth': WETH_CONTRACT,
+    'usdc': USDC_CONTRACT
+}
+
 
 def check_balance(account, token='slp'):
-    if token == 'slp':
-        contract = SLP_CONTRACT
-    elif token == 'axs':
-        contract = AXS_CONTRACT
-    elif token == "axies":
-        contract = AXIE_CONTRACT
-    elif token == "weth":
-        contract = WETH_CONTRACT
-    else:
-        return 0
-
     w3 = Web3(
             Web3.HTTPProvider(
                 RONIN_PROVIDER,
                 request_kwargs={
                     "headers": {"content-type": "application/json",
                                 "user-agent": USER_AGENT}}))
+    if token.lower() in TOKENS:
+        contract = TOKENS[token.lower()]
+    elif token.lower() == "ron":
+        return float(w3.eth.get_balance(Web3.toChecksumAddress(account.replace("ronin:", "0x"))) / 1000000000000000000)
+    else:
+        return 0
     ctr = w3.eth.contract(
         address=Web3.toChecksumAddress(contract),
         abi=BALANCE_ABI
